Class: PulpHuggingFaceClient::HuggingFaceHuggingFaceContent

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb

Overview

A Serializer for HuggingFaceContent.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HuggingFaceHuggingFaceContent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpHuggingFaceClient::HuggingFaceHuggingFaceContent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpHuggingFaceClient::HuggingFaceHuggingFaceContent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'repository')
    self.repository = attributes[:'repository']
  end

  if attributes.key?(:'overwrite')
    self.overwrite = attributes[:'overwrite']
  end

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'artifact')
    self.artifact = attributes[:'artifact']
  else
    self.artifact = nil
  end

  if attributes.key?(:'relative_path')
    self.relative_path = attributes[:'relative_path']
  else
    self.relative_path = nil
  end

  if attributes.key?(:'repo_id')
    self.repo_id = attributes[:'repo_id']
  else
    self.repo_id = nil
  end

  if attributes.key?(:'repo_type')
    self.repo_type = attributes[:'repo_type']
  end

  if attributes.key?(:'revision')
    self.revision = attributes[:'revision']
  else
    self.revision = 'main'
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'etag')
    self.etag = attributes[:'etag']
  end

  if attributes.key?(:'last_modified')
    self.last_modified = attributes[:'last_modified']
  end
end

Instance Attribute Details

#artifactObject

Artifact file representing the physical content



29
30
31
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 29

def artifact
  @artifact
end

#etagObject

ETag from Hugging Face



47
48
49
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 47

def etag
  @etag
end

#last_modifiedObject

Last modified timestamp



50
51
52
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 50

def last_modified
  @last_modified
end

#overwriteObject

When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when 'repository' is specified. Defaults to true.



23
24
25
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 23

def overwrite
  @overwrite
end

#pulp_labelsObject

A dictionary of arbitrary key/value pairs used to describe a specific Content instance.



26
27
28
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 26

def pulp_labels
  @pulp_labels
end

#relative_pathObject

The relative path within the repository



32
33
34
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 32

def relative_path
  @relative_path
end

#repo_idObject

The Hugging Face repository ID (e.g., 'microsoft/DialoGPT-medium')



35
36
37
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 35

def repo_id
  @repo_id
end

#repo_typeObject

The type of Hugging Face repository * models - Models * datasets - Datasets * spaces - Spaces



38
39
40
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 38

def repo_type
  @repo_type
end

#repositoryObject

A URI of a repository the new content unit should be associated with.



20
21
22
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 20

def repository
  @repository
end

#revisionObject

The git revision/branch/tag



41
42
43
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 41

def revision
  @revision
end

#sizeObject

File size in bytes



44
45
46
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 44

def size
  @size
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 351

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpHuggingFaceClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 75

def self.attribute_map
  {
    :'repository' => :'repository',
    :'overwrite' => :'overwrite',
    :'pulp_labels' => :'pulp_labels',
    :'artifact' => :'artifact',
    :'relative_path' => :'relative_path',
    :'repo_id' => :'repo_id',
    :'repo_type' => :'repo_type',
    :'revision' => :'revision',
    :'size' => :'size',
    :'etag' => :'etag',
    :'last_modified' => :'last_modified'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 327

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
118
119
120
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 114

def self.openapi_nullable
  Set.new([
    :'size',
    :'etag',
    :'last_modified'
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 97

def self.openapi_types
  {
    :'repository' => :'String',
    :'overwrite' => :'Boolean',
    :'pulp_labels' => :'Hash<String, String>',
    :'artifact' => :'String',
    :'relative_path' => :'String',
    :'repo_id' => :'String',
    :'repo_type' => :'RepoTypeEnum',
    :'revision' => :'String',
    :'size' => :'Integer',
    :'etag' => :'String',
    :'last_modified' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 296

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      repository == o.repository &&
      overwrite == o.overwrite &&
      pulp_labels == o.pulp_labels &&
      artifact == o.artifact &&
      relative_path == o.relative_path &&
      repo_id == o.repo_id &&
      repo_type == o.repo_type &&
      revision == o.revision &&
      size == o.size &&
      etag == o.etag &&
      last_modified == o.last_modified
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 422

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


314
315
316
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 314

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



320
321
322
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 320

def hash
  [repository, overwrite, pulp_labels, artifact, relative_path, repo_id, repo_type, revision, size, etag, last_modified].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 194

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @artifact.nil?
    invalid_properties.push('invalid value for "artifact", artifact cannot be nil.')
  end

  if @relative_path.nil?
    invalid_properties.push('invalid value for "relative_path", relative_path cannot be nil.')
  end

  if @relative_path.to_s.length < 1
    invalid_properties.push('invalid value for "relative_path", the character length must be great than or equal to 1.')
  end

  if @repo_id.nil?
    invalid_properties.push('invalid value for "repo_id", repo_id cannot be nil.')
  end

  if @repo_id.to_s.length < 1
    invalid_properties.push('invalid value for "repo_id", the character length must be great than or equal to 1.')
  end

  if !@revision.nil? && @revision.to_s.length < 1
    invalid_properties.push('invalid value for "revision", the character length must be great than or equal to 1.')
  end

  if !@etag.nil? && @etag.to_s.length < 1
    invalid_properties.push('invalid value for "etag", the character length must be great than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



398
399
400
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 398

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 404

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



392
393
394
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 392

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



230
231
232
233
234
235
236
237
238
239
240
# File 'lib/pulp_hugging_face_client/models/hugging_face_hugging_face_content.rb', line 230

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @artifact.nil?
  return false if @relative_path.nil?
  return false if @relative_path.to_s.length < 1
  return false if @repo_id.nil?
  return false if @repo_id.to_s.length < 1
  return false if !@revision.nil? && @revision.to_s.length < 1
  return false if !@etag.nil? && @etag.to_s.length < 1
  true
end